# -*- coding: utf-8 -*-
# Copyright 2009-2014, Red Hat, Inc.
# License: GPL-2.0+ <http://spdx.org/licenses/GPL-2.0+>
# See the LICENSE file for more details on Licensing

'''py.test configuration and plugins
Read more at: http://pytest.org/latest/plugins.html#conftest-py-plugins'''

import os
import logging
import tempfile

import libtaskotron.config
import libtaskotron.logger


def pytest_addoption(parser):
    """
    Add an option to the py.test parser to detect when the functional tests
    should be detected and run
    """

    parser.addoption('-F', '--functional', action='store_true', default=False,
                     help='Add functional tests')


def pytest_ignore_collect(path, config):
    """Prevents collection of any files named functest* to speed up non
        integration tests"""
    if path.fnmatch('*functest*'):
        try:
            is_functional = config.getvalue('functional')
        except KeyError:
            return True

        return not is_functional


def pytest_configure(config):
    """Called after command line options have been parsed and all plugins and
    initial conftest files been loaded."""

    # set a testing config profile
    os.environ[libtaskotron.config.PROFILE_VAR] = \
        libtaskotron.config.ProfileName.TESTING

    # create temporary directories instead of using real system directories
    testdir = tempfile.mkdtemp(prefix='taskotron-test-')
    libtaskotron.config_defaults.Config.tmpdir = testdir + '/tmpdir'
    libtaskotron.config_defaults.Config.logdir = testdir + '/logdir'

    # enable debug logging for taskotron
    # This will allow us to use libtaskotron-logged output for failed tests.
    # You can also use "py.test -s" option to see all output even for passed
    # tests (of course, it's better to run the suite with just a single file
    # rather than the whole directory in this case)
    libtaskotron.logger.init(level=logging.DEBUG)
